@@ -11,7 +11,7 @@ use safecast::AsType;
 
 use tc_btree::{BTreeType, Node};
 use tc_error::*;
-use tc_transact::fs::{Dir, File, Hash};
+use tc_transact::fs::{Dir, File};
 use tc_transact::{IntoView, Transaction, TxnId};
 use tc_value::Value;
 use tcgeneric::{
@@ -442,16 +442,6 @@ where
     }
 }
 
-#[async_trait]
-impl<'en, F: File<Node>, D: Dir, Txn: Transaction<D>> Hash<'en, D> for Table<F, D, Txn> {
-    type Item = Vec<Value>;
-    type Txn = Txn;
-
-    async fn hashable(&'en self, txn: &'en Txn) -> TCResult<TCBoxTryStream<'en, Self::Item>> {
-        self.clone().rows(*txn.id()).await
-    }
-}
-
 #[async_trait]
 impl<F: File<Node>, D: Dir, Txn: Transaction<D>> de::FromStream for Table<F, D, Txn>
 where
